package mallmanage

import (
	"errors"
	"github.com/codinl/go-logger"
	"github.com/gin-gonic/gin"
	"github.com/rs/zerolog/log"
	"go-admin/app/admin/models"
	"go-admin/tools/app"
	"net/http"
)

func GoodsOrderList(c *gin.Context) {
	req := &models.GoodsOrderListReq{}
	if c.ShouldBindJSON(req) != nil {
		logger.Errorf("para err")
		app.Error(c, http.StatusBadRequest, errors.New("para err"), "参数错误")
		return
	}

	sysUser, err := models.GetSysUserByCtx(c)
	if err != nil {
		logger.Errorf("err:%#v", err)
		app.Error(c, http.StatusInternalServerError, errors.New("order list  err"), "获取订单列表失败")
		return
	}
	if sysUser.StoreId != 13 && sysUser.StoreId != 0 {
		logger.Errorf("err:%#v", err)
		app.Error(c, http.StatusInternalServerError, errors.New("order list  err"), "没有权限")
		return
	}
	orderList, totalCount, err := req.OrderList()
	if err != nil {
		logger.Errorf("err:%#v", err)
		msg := "获取订单列表失败"
		app.Error(c, http.StatusInternalServerError, errors.New("order list  err"), msg)
		return
	}
	ret := map[string]interface{}{
		"count":      totalCount,
		"list":       orderList,
		"page_index": req.PageIdx,
		"page_size":  req.PageSize,
		//"total_page": totalPage,
	}
	app.OK(c, ret, "")
}

func GoodsOrderDetail(c *gin.Context) {
	req := &models.GoodsOrderDetailReq{}
	if c.ShouldBindJSON(req) != nil {
		logger.Errorf("para err")
		app.Error(c, http.StatusBadRequest, errors.New("para err"), "参数错误")
		return
	}
	orderDetail, err := req.OrderDetail()
	if err != nil {
		logger.Errorf("err:%#v", err)
		msg := "获取订单详情失败"
		app.Error(c, http.StatusInternalServerError, errors.New("order detail  err"), msg)
		return
	}

	app.OK(c, orderDetail, "")
}

func GoodsOrderDeliver(c *gin.Context) {
	req := &models.GoodsOrderDeliverReq{}
	if c.ShouldBindJSON(req) != nil {
		logger.Errorf("para err")
		app.Error(c, http.StatusBadRequest, errors.New("para err"), "参数错误")
		return
	}

	sysUser, err := models.GetSysUserByCtx(c)
	if err != nil {
		log.Error().Msgf("get sys user err:%#v", err)
		app.Error(c, http.StatusInternalServerError, errors.New("order detail  err"), "订单发货失败")
		return
	}
	req.DeliverStoreId = sysUser.StoreId

	orderDetail, err := req.OrderDeliver()
	if err != nil {
		logger.Errorf("err:%#v", err)
		msg := "订单发货失败"
		app.Error(c, http.StatusInternalServerError, errors.New("order detail  err"), msg)
		return
	}

	app.OK(c, orderDetail, "订单发货成功")
}

func GoodsOrderRefundSendReceive(c *gin.Context) {
	req := &models.GoodsOrderRefundSendReceiveReq{}
	if c.ShouldBindJSON(req) != nil {
		logger.Errorf("para err")
		app.Error(c, http.StatusBadRequest, errors.New("para err"), "参数错误")
		return
	}

	sysUser, err := models.GetSysUserByCtx(c)
	if err != nil {
		log.Error().Msgf("get sys user err:%#v", err)
		app.Error(c, http.StatusInternalServerError, errors.New("order detail  err"), "订单发货失败")
		return
	}
	req.SysUser = *sysUser

	err = req.Receive()
	if err != nil {
		logger.Errorf("err:%#v", err)
		msg := "订单发货失败"
		app.Error(c, http.StatusInternalServerError, errors.New("order detail  err"), msg)
		return
	}

	app.OK(c, nil, "订单退货成功")
}

func MallUserVmRecord(c *gin.Context) {
	req := &models.MallUserVmRecordReq{}
	if c.ShouldBindJSON(req) != nil {
		logger.Errorf("para err")
		app.Error(c, http.StatusBadRequest, errors.New("para err"), "参数错误")
		return
	}
	orderList, totalCount, err := req.MallUserVmRecordList()
	if err != nil {
		logger.Errorf("err:%#v", err)
		msg := "获取用户积分记录列表失败"
		app.Error(c, http.StatusInternalServerError, errors.New("order detail  err"), msg)
		return
	}
	ret := map[string]interface{}{
		"count":      totalCount,
		"list":       orderList,
		"page_index": req.PageIdx,
		"page_size":  req.PageSize,
		//"total_page": totalPage,
	}
	app.OK(c, ret, "")
}
